from django.urls import reverse
from rest_framework import viewsets
from rest_framework import permissions
from rest_framework import status
from rest_framework.response import Response

from uhepp_vault.models import Plot
from .serializers import PlotSerializer

class CreateModelMixin:
    """Create a model instance with Location header"""
    def create(self, request, *args, **kwargs):
        serializer = self.get_serializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        obj = self.perform_create(serializer)
        headers = self.get_success_headers(obj)
        return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)

    def perform_create(self, serializer):
        obj = serializer.save()
        return obj

    def get_success_headers(self, obj):
        rel_url = reverse('uhepp_api:plot-detail', args=[obj.uuid])
        url = self.request.build_absolute_uri(rel_url)
        return {'Location': url}
    
class PlotSet(CreateModelMixin,
                   viewsets.mixins.RetrieveModelMixin,
                   viewsets.GenericViewSet):
    queryset = Plot.objects.all()
    serializer_class = PlotSerializer
    permission_classes = []
